@@ -20,7 +20,9 @@ module Data.HashTable.Internal.IntArray
 import           Control.Monad.ST
 import           Data.Bits
 import qualified Data.Primitive.ByteArray as A
+#if !MIN_VERSION_primitive(0,7,0)
 import           Data.Primitive.Types     (Addr (..))
+#endif
 import           GHC.Exts
 import           GHC.Word
 import           Prelude                  hiding (length)
@@ -112,4 +114,8 @@ length (IA a) = A.sizeofMutableByteArray a `div` wordSizeInBytes
 toPtr :: IntArray s -> Ptr a
 toPtr (IA a) = Ptr a#
   where
+#if MIN_VERSION_primitive(0,7,0)
+    !(Ptr !a#) = A.mutableByteArrayContents a
+#else
     !(Addr !a#) = A.mutableByteArrayContents a
+#endif
